/******************************************************
 *
 * Name:         usp_Backup_Log2File.sql
 *     
 * Design Phase:
 *     Author:   John Miner
 *     Date:     04-26-2011
 *     Purpose:  Backup the transaction log to a file.
 * 
 ******************************************************/

/*  
	Which database to use.
*/

USE msdb
GO


/*  
	Delete the existing stored procedure.
*/

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[usp_Backup_Log2File]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[usp_Backup_Log2File]
GO
 


/*  
	Create the new stored procedure.
*/

CREATE PROCEDURE [dbo].[usp_Backup_Log2File]
  @VAR_PATH VARCHAR (250) = 'G:\MSSQL.DEFAULT\BACKUP',  
  @VAR_NAME VARCHAR (250) = 'MSDB',  
  @VAR_SCHEMA INT = 1,
  @VAR_FORMAT INT = 0
AS
BEGIN

-- DECLARE VARIABLES
DECLARE @VAR_FILE VARCHAR(250);
DECLARE @VAR_DAY VARCHAR(3);
DECLARE @VAR_DESC VARCHAR(250);


-- WEEKDAY BACKUP PLAN
IF (@VAR_SCHEMA  = 1)
  BEGIN
    SELECT @VAR_DAY = 
    CASE DATEPART(dw, GETDATE())
        WHEN 1 THEN 'SUN'
        WHEN 2 THEN 'MON'
        WHEN 3 THEN 'TUE'
        WHEN 4 THEN 'WED'
        WHEN 5 THEN 'THU'
        WHEN 6 THEN 'FRI'
        WHEN 7 THEN 'SAT'
    END;
  END
  
-- DAILY BACKUP PLAN
ELSE
  BEGIN
    SELECT @VAR_DAY = REPLACE(STR(DATEPART(d, GETDATE()), 3, 0), ' ', '0');
  END;


-- MAKE UP FILE NAME
SELECT @VAR_FILE = @VAR_PATH + '\' + UPPER(@VAR_NAME) + '\' + UPPER(@VAR_NAME) + '_' + @VAR_DAY + '_LOG.TRN';

-- SHOW THE FINAL NAME
PRINT 'BACKUP THE FOLLOWING LOG TO FILE:'
PRINT '    ' + @VAR_FILE;

-- MAKE UP THE DESCRIPTION
SELECT @VAR_DESC = UPPER(@VAR_NAME) + ' - Transaction Log Backup';


-- OVERWRITE EXISTING FILE
IF (@VAR_FORMAT  = 1)
  BEGIN 
    BACKUP LOG @VAR_NAME
    TO DISK = @VAR_FILE
    WITH  
	    FORMAT, 
	    INIT,  
	    NAME = @VAR_DESC, 
	    SKIP, 
	    NOREWIND, 
	    NOUNLOAD,  
	    STATS = 10;
	END
		
-- APPEND 2 EXISTING FILE
ELSE
  BEGIN 
    BACKUP LOG @VAR_NAME
    TO DISK = @VAR_FILE
    WITH  
	    NOFORMAT, 
	    NOINIT,  
	    NAME = @VAR_DESC, 
	    SKIP, 
	    NOREWIND, 
	    NOUNLOAD,  
	    STATS = 10;
	END
	    
END
GO
