/******************************************************
 *
 * Name:         usp_Truncate_Log_File_GT2005
 *     
 * Design Phase:
 *     Author:   John Miner
 *     Date:     05-25-2011
 *     Purpose:  Use this procedure will databases
 *               like model that you really do not care
 *               about the log file.  A full backup
 *               should be taken after this action.
 * 
 ******************************************************/

/*  
	Which database to use.
*/

USE msdb
GO


/*  
	Delete the existing stored procedure.
*/

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[usp_Truncate_Log_File_GT2005]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[usp_Truncate_Log_File_GT2005];
GO
 


/*  
	Create the new stored procedure.
*/

CREATE PROCEDURE [dbo].[usp_Truncate_Log_File_GT2005] 
  @VAR_LOGICAL_NAME VARCHAR (250),
  @VAR_LOG_FILE_NAME VARCHAR (250),
  @VAR_LOG_SIZE VARCHAR (10)
AS
BEGIN

    -- Declare variables
    DECLARE @VAR_SQL_STMT VARCHAR(MAX);
    DECLARE @VAR_MODEL VARCHAR(15);
    
    -- RECOVERY { FULL | BULK_LOGGED | SIMPLE }     
    SELECT @VAR_MODEL = UPPER(ISNULL(recovery_model_desc, 'FULL')) 
    FROM sys.databases d (NOLOCK)
    WHERE d.name = @VAR_LOGICAL_NAME;
    
    -- Truncate the log by changing recovery model to simple.
    IF (@VAR_MODEL <> 'SIMPLE')
    BEGIN
        SET @VAR_SQL_STMT = 'ALTER DATABASE ' +  @VAR_LOGICAL_NAME  + ' SET RECOVERY SIMPLE;';
        EXEC(@VAR_SQL_STMT);
    END;

    -- Shrink the truncated log file to 1 MB.
    SET @VAR_SQL_STMT = 'USE [' + @VAR_LOGICAL_NAME + '];DBCC SHRINKFILE ( ' + @VAR_LOG_FILE_NAME + ' , ' + @VAR_LOG_SIZE + ');';
    EXEC(@VAR_SQL_STMT);

    -- Reset the database recovery model.
    IF (@VAR_MODEL <> 'SIMPLE')
    BEGIN
        SET @VAR_SQL_STMT = 'ALTER DATABASE ' +  @VAR_LOGICAL_NAME  + ' SET RECOVERY ' + @VAR_MODEL + ';';
        EXEC(@VAR_SQL_STMT);
    END;
END
GO

