/******************************************************
 *
 * Name:         usp_Verify_Backup4Log.sql
 *     
 * Design Phase:
 *     Author:   John Miner
 *     Date:     04-26-2011
 *     Purpose:  Verify the backup of the transaction log.
 * 
 ******************************************************/

/*  
	Which database to use.
*/

USE msdb
GO


/*  
	Delete the existing stored procedure.
*/

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[usp_Verify_Backup4Log]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[usp_Verify_Backup4Log]
GO
 


/*  
	Create the new stored procedure.
*/

CREATE PROCEDURE [dbo].[usp_Verify_Backup4Log]
  @VAR_PATH VARCHAR (250) = 'G:\MSSQL.DEFAULT\BACKUP',  
  @VAR_NAME VARCHAR (250),  
  @VAR_SCHEMA INT = 1
AS
BEGIN

-- DECLARE VARIABLES
DECLARE @VAR_FILE VARCHAR(250);
DECLARE @VAR_DAY VARCHAR(3);
DECLARE @VAR_DESC VARCHAR(250);
DECLARE @VAR_BACKUP_SET_ID INT;

-- WEEKDAY BACKUP PLAN
IF (@VAR_SCHEMA  = 1)
  BEGIN
    SELECT @VAR_DAY = 
    CASE DATEPART(dw, GETDATE())
        WHEN 1 THEN 'SUN'
        WHEN 2 THEN 'MON'
        WHEN 3 THEN 'TUE'
        WHEN 4 THEN 'WED'
        WHEN 5 THEN 'THU'
        WHEN 6 THEN 'FRI'
        WHEN 7 THEN 'SAT'
    END;
  END
  
-- DAILY BACKUP PLAN
ELSE
  BEGIN
    SELECT @VAR_DAY = REPLACE(STR(DATEPART(d, GETDATE()), 3, 0), ' ', '0');
  END;

-- MAKE UP FILE NAME
SELECT @VAR_FILE = @VAR_PATH + '\' + UPPER(@VAR_NAME) + '\' + UPPER(@VAR_NAME) + '_'  + @VAR_DAY + '_LOG.TRN';

-- SHOW THE FINAL NAME
PRINT 'VERIFY THE LOG FILE: '
PRINT '    ' + @VAR_FILE;

-- GET THE LATEST BACKUP SET ID
SELECT @VAR_BACKUP_SET_ID = position 
from msdb..backupset 
where 
    database_name = @VAR_NAME and 
    backup_set_id=(select max(backup_set_id) from msdb..backupset where database_name = @VAR_NAME);

-- BACKUP DID NOT WORK ...
IF @VAR_BACKUP_SET_ID  is null 
BEGIN
    SELECT @VAR_DESC = 'Verify failed.  Backup information for database [' + @VAR_NAME + ' not found.';
    RAISERROR(@VAR_DESC, 16, 1);
END;

-- VERIFY THE  BACKUP
RESTORE VERIFYONLY 
FROM DISK = @VAR_FILE 
WITH  
    FILE = @VAR_BACKUP_SET_ID,  
    NOUNLOAD,  
    NOREWIND;
END
GO
