/******************************************************
 *
 * Name:         usp_Verify_Db_Integrity.sql
 *     
 * Design Phase:
 *     Author:   John Miner
 *     Date:     04-26-2011
 *     Purpose:  Verify the integrity of the database files.
 * 
 ******************************************************/

/*  
	Which database to use.
*/

USE msdb
GO


/*  
	Delete the existing stored procedure.
*/

IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[usp_Verify_Db_Integrity]') AND type in (N'P', N'PC'))
DROP PROCEDURE [dbo].[usp_Verify_Db_Integrity]
GO
 


/*  
	Create the new stored procedure.
*/

CREATE PROCEDURE [dbo].[usp_Verify_Db_Integrity]
  @VAR_NAME VARCHAR (250),
  @VAR_NOINDEX INT = 0
AS
BEGIN

-- Checks the logical and physical integrity of all the objects in the 
--   specified database by performing the following operations: 

-- 1. Runs DBCC CHECKALLOC on the database.
-- 2. Runs DBCC CHECKTABLE on every table and view in the database.
-- 3. Runs DBCC CHECKCATALOG on the database.

  -- EXECUTE THE CHECK ON THE CORRECT DATABASE
  IF (@VAR_NOINDEX = 0)
      DBCC CHECKDB(@VAR_NAME)
  ELSE
      DBCC CHECKDB(@VAR_NAME, NOINDEX);  
END
GO
